@@ -2,7 +2,7 @@ import seaborn as sns
 import statsmodels.api as sm
 from matplotlib import pyplot as plt
 
-from imodels.experimental.bartpy.sklearnmodel import SklearnModel
+from ..sklearnmodel import SklearnModel
 
 
 def plot_qq(model: SklearnModel, ax=None) -> None:
